import java.io.File;
import java.io.IOException;
import java.util.InputMismatchException;
import java.util.LinkedList;
import java.util.List;
import java.util.Scanner;
import java.util.regex.Pattern;

import car.Car;
import car.util.Color;

public class CarsMain {

    public static void main(String[] args) throws IOException {
        List<Car> cars = loadCars(args[0]);
        for (Car car : cars) {
            System.out.println(car);
        }
    }

    private static List<Car> loadCars(String path) throws IOException {
        List<Car> cars = new LinkedList<>();
        try (Scanner scanner = new Scanner(new File(path))) {
            while (scanner.hasNext()) {
                Car car = tryToCreateCar(scanner.next(), scanner.next(), scanner.next());
                if (car != null) {
                    cars.add(car);
                }
            }
        }
        return cars;
    }

    private static Car tryToCreateCar(String licencePlate, String colorText, String maxSpeedText) {
        try {
            if (!Pattern.matches("[A-Z]{3}-[0-9]{3}", licencePlate)) {
                throw new IllegalArgumentException("invalid licence plate: " + licencePlate);
            }
            Color color = Color.valueOf(colorText);
            int maxSpeed = Integer.parseInt(maxSpeedText);
            return new Car(licencePlate, color, maxSpeed);
        } catch (IllegalArgumentException | InputMismatchException e) {
            System.err.println("Parsing error: " + e.getMessage());
        }
        return null;
    }

}